# MediaWiki Scraper

This is a placeholder for the project currently titled [`wikiteam3`](https://github.com/elsiehupp/wikiteam3), which will be renamed in order to avoid confusion with the upstream [WikiTeam](https://github.com/WikiTeam/wikiteam/) project.
